@@ -19,7 +19,7 @@
  * USA
  */
 
-#include "config.h"
+#include <config.h>
 
 #include <string.h>
 #include <locale.h>
@@ -50,6 +50,7 @@
 #include <hildon-widgets/hildon-program.h>
 #else
 #include <hildon/hildon-program.h>
+#include <tablet-browser-interface.h>
 #endif /* HAVE_MAEMO_3 */
 
 #define SERVICE_NAME "org.gnome.Games.AisleRiot"
@@ -60,8 +61,9 @@
 #include <windows.h>
 #include <io.h>
 #define HELP_EXT "xhtml"
-//FIXME On win32 help is created as html with gnome-doc-tool,
-//and put manually in the directory below.
+/* FIXME On win32 help is created as html with gnome-doc-tool,
+ * and put manually in the directory below.
+ */
 #define HELPDIR PKGDATADIR "/aisleriot/help"
 #endif /* G_OS_WIN32 */
 
@@ -645,12 +647,19 @@ main_prog (void *closure, int argc, char *argv[])
   /* FIXMEchpe sort of strange that maemo doesn't all of this out-of-the-box... */
   g_object_set (gtk_widget_get_settings (GTK_WIDGET (data.window)),
                 "gtk-alternative-button-order", TRUE,
-                "gtk-menu-images", FALSE,
-                "gtk-button-images", FALSE,
                 "gtk-toolbar-style", (glong) GTK_TOOLBAR_ICONS,
+                "gtk-menu-images", FALSE,
+#ifdef HAVE_MAEMO_3
+                "gtk-button-images", FALSE,
+#endif /* HAVE_MAEMO_3 */
 #if GTK_CHECK_VERSION (2, 10, 0)
-                "gtk-enable-accels", FALSE,
                 "gtk-enable-mnemonics", FALSE,
+
+                /* We want the default of FALSE for this property, but to work
+                 * around https://bugs.maemo.org/show_bug.cgi?id=2278 we have
+                 * to set this to TRUE.
+                 */
+                "gtk-enable-accels", TRUE,
 #else
                 "hildon-keyboard-shortcuts", FALSE,
 #endif /* GTK 2.10.0 */
@@ -697,8 +706,8 @@ main (int argc, char *argv[])
 
   setlocale (LC_ALL, "");
 
-#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
-  /* If we're going to use gnome-vfs, we need to init threads before
+#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS) || defined(HAVE_GSTREAMER)
+  /* If we're going to use gnome-vfs or gstreamer, we need to init threads before
    * calling any glib functions.
    */
   g_thread_init (NULL);
