@@ -2,7 +2,7 @@
  * File: support.c
  * Author: Justin Zaun
  * Project: GGZ GTK Client
- * $Id: support.h 5572 2006-10-14 10:32:58Z andreasr $
+ * $Id$
  *
  * Support code
  *
@@ -92,11 +92,6 @@ GtkWidget*  ggz_lookup_widget              (GtkWidget       *widget,
  */
 char *nocasestrstr (char *text, char *tofind);
 
-/*
- * Use this function to load a URL in netscape
- */
-int support_goto_url(gchar *url);
-
 /*
  * Use this function to fork a command
  */
