@@ -167,7 +167,6 @@ class GtkNewGameDialog:
         levels = [('easy',   _('Easy'),   'weather-few-clouds'),
                   ('normal', _('Normal'), 'weather-overcast'),
                   ('hard',   _('Hard'),   'weather-storm')]
-        iconTheme = gtk.icon_theme_get_default()
         for (key, label, icon) in levels:
             iter = levelModel.append()
             levelModel.set(iter, 0, key, 1, icon, 2, label)
@@ -425,37 +424,26 @@ class GtkLoadGameDialog:
         fileChooser.add_filter(allFilter)
         
         self.window.present()
-        
-    def __getFilename(self):
-        """Get the currently selected filename.
-        
-        Returns the filename (string) or None if none selected.
-        """
-        return self.__gui.get_widget('filechooserwidget').get_filename()
-    
-    def _on_file_changed(self, widget):
-        """Gtk+ callback"""
-        name = self.__getFilename()
-        if name is None:
-            isFile = False
-        else:
-            isFile = os.path.isfile(name)
-        self.__gui.get_widget('properties_button').set_sensitive(isFile)
-        self.__gui.get_widget('open_button').set_sensitive(isFile)
-        
+            
     def _on_file_activated(self, widget):
         """Gtk+ callback"""
         self._on_response(self.window, gtk.RESPONSE_OK)
 
     def _on_response(self, dialog, responseId):
         """Gtk+ callback"""
-        chooser= self.__gui.get_widget('filechooserwidget')
+        chooser = self.__gui.get_widget('filechooserwidget')
 
         if responseId == gtk.RESPONSE_OK or responseId == gtk.RESPONSE_YES:
             folder = chooser.get_current_folder()
             if folder is not None:
                 glchess.config.set('load_directory', folder)
-            error = self.__mainUI.feedback.loadGame(self.__getFilename(), responseId == gtk.RESPONSE_YES)
+
+            fileName = self.__gui.get_widget('filechooserwidget').get_filename()
+            if fileName is None:
+                return #error = _('Please select a file to load')
+            else:
+                error = self.__mainUI.feedback.loadGame(fileName, responseId == gtk.RESPONSE_YES)
+
             if error is not None:
                 self.firstExpose = True
                 self.__gui.get_widget('error_box').show()
@@ -644,6 +632,8 @@ class GtkPreferencesDialog:
         """Gtk+ callback"""
         model = widget.get_model()
         iter = widget.get_active_iter()
+        if iter is None:
+            return
         data = model.get(iter, 1)
         if data[0] is not None:
             glchess.config.set('move_format', data[0])
@@ -652,6 +642,8 @@ class GtkPreferencesDialog:
         """Gtk+ callback"""
         model = widget.get_model()
         iter = widget.get_active_iter()
+        if iter is None:
+            return
         data = model.get(iter, 1)
         if data[0] is not None:
             glchess.config.set('board_view', data[0])
@@ -660,6 +652,8 @@ class GtkPreferencesDialog:
         """Gtk+ callback"""
         model = widget.get_model()
         iter = widget.get_active_iter()
+        if iter is None:
+            return
         data = model.get(iter, 1)
         if data[0] is not None:
             glchess.config.set('promotion_type', data[0])
