@@ -201,6 +201,7 @@ class GtkUI(glchess.ui.UI):
                                properties={gnome.PARAM_APP_DATADIR: APP_DATA_DIR})
 
         self.feedback = feedback
+        self._watches = {}
         self.__networkGames = {}
         self.__saveGameDialogs = {}
         self.__joinGameDialogs = []
@@ -220,29 +221,20 @@ class GtkUI(glchess.ui.UI):
         self._gui = loadGladeFile('glchess.glade')
         self._gui.signal_autoconnect(self)
         
-        # Create mappings between the promotion radio buttons and the promotion types
-        self.__promotionTypeByRadio = {}
-        self.__promotionRadioByType = {}
-        for piece in ['queen', 'knight', 'rook', 'bishop']:
-            widget = self.__getWidget('promotion_%s_radio' % piece)
-            self.__promotionTypeByRadio[widget] = piece
-            self.__promotionRadioByType[piece] = widget
-
-        # Create mappings between the board view radio buttons and the config names
-        self.__boardViewRadioByType = {}
-        self.__boardViewTypeByRadio = {}
-        for name in ['white', 'black', 'human', 'current']:
-            widget = self.__getWidget('menu_side_%s' % name)
-            self.__boardViewTypeByRadio[widget] = name
-            self.__boardViewRadioByType[name] = widget
-
+        self.mainWindow = self._gui.get_widget('glchess_app')
+        
+        # Workaround as Glade 2 always overrides the system style for toolbars
+        self.__getWidget('toolbar').unset_style()
+        
         # Create the model for the player types
         self.__playerModel = gtk.ListStore(str, str, str)
-        iconTheme = gtk.icon_theme_get_default()
         iter = self.__playerModel.append()
         self.__playerModel.set(iter, 0, '', 1, 'stock_person', 2, _('Human'))
         
         self.__logWindow = log.LogWindow(self._gui.get_widget('log_notebook'))
+        
+        # Make preferences dialog
+        self.preferences = dialogs.GtkPreferencesDialog(self)
 
         # Balance space on each side of the history combo
         group = gtk.SizeGroup(gtk.SIZE_GROUP_BOTH)
@@ -297,7 +289,11 @@ class GtkUI(glchess.ui.UI):
     
     def watchFileDescriptor(self, fd):
         """Extends ui.UI"""
-        gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_HUP, self.__readData)
+        self._watches[fd] = gobject.io_add_watch(fd, gobject.IO_IN | gobject.IO_HUP, self.__readData)
+        
+    def unwatchFileDescriptor(self, fd):
+        """Extends ui.UI"""
+        gobject.source_remove(self._watches.pop(fd))
         
     def writeFileDescriptor(self, fd):
         """Extends ui.UI"""
@@ -325,7 +321,6 @@ class GtkUI(glchess.ui.UI):
         'name' is the name of the engine.
         TODO: difficulty etc etc
         """
-        iconTheme = gtk.icon_theme_get_default()
         iter = self.__playerModel.append()
         self.__playerModel.set(iter, 0, name, 1, 'stock_notebook', 2, name)
         
@@ -370,7 +365,7 @@ class GtkUI(glchess.ui.UI):
         else:
             # Translators: This is the window title when not playing a game
             title = _('Chess')            
-        self._gui.get_widget('glchess_app').set_title(title)
+        self.mainWindow.set_title(title)
 
     def addLogWindow(self, title, executable, description):
         """
@@ -416,7 +411,7 @@ class GtkUI(glchess.ui.UI):
                 self.__applyConfig(name, value)
         self.__resize()
         
-        self._gui.get_widget('glchess_app').show()
+        self.mainWindow.show()
 
         # Apply the fullscreen flag after the window has been shown otherwise
         # gtk.Window.unfullscreen() stops working if the window is set to fullscreen
@@ -498,7 +493,7 @@ class GtkUI(glchess.ui.UI):
     def __updateAttention(self):
         """
         """
-        widget = self._gui.get_widget('glchess_app')
+        widget = self.mainWindow
         widget.set_urgency_hint(self.__attentionCounter != 0 and not widget.is_active())
         
     def _on_focus_changed(self, widget, event):
@@ -526,7 +521,7 @@ class GtkUI(glchess.ui.UI):
         except glchess.config.Error:
             return
         
-        self._gui.get_widget('glchess_app').resize(width, height)
+        self.mainWindow.resize(width, height)
 
     def __applyConfig(self, name, value):
         """
@@ -538,12 +533,9 @@ class GtkUI(glchess.ui.UI):
         # Show/hide the toolbar
         if name == 'show_toolbar':
             toolbar = self.__getWidget('toolbar')
-            menu = self.__getWidget('menu_view_toolbar')
             if value is True:
-                menu.set_active(True)
                 toolbar.show()
             else:
-                menu.set_active(False)
                 toolbar.hide()
                 
         elif name == 'enable_networking':
@@ -559,17 +551,14 @@ class GtkUI(glchess.ui.UI):
         # Show/hide the history
         elif name == 'show_history':
             box = self.__getWidget('navigation_box')
-            menu = self.__getWidget('menu_view_history')
             if value is True:
-                menu.set_active(True)
                 box.show()
             else:
-                menu.set_active(False)
                 box.hide()
                 
         # Maximised mode
         elif name == 'maximised':
-            window = self._gui.get_widget('glchess_app')
+            window = self.mainWindow
             if value is True:
                 window.maximize()
             else:
@@ -577,7 +566,7 @@ class GtkUI(glchess.ui.UI):
 
         # Fullscreen mode
         elif name == 'fullscreen':
-            window = self._gui.get_widget('glchess_app')
+            window = self.mainWindow
             if value is True:
                 window.fullscreen()
             else:
@@ -605,40 +594,23 @@ Please contact your system administrator to resolve these problems, until then y
             self.view.viewWidget.setRenderGL(self.__renderGL)
                 
         elif name == 'show_comments':
-            menuItem = self.__getWidget('menu_view_comment')
-            menuItem.set_active(value)
             self.view.setShowComments(value)
 
         elif name == 'show_move_hints':
-            menuItem = self.__getWidget('menu_view_move_hints')
-            menuItem.set_active(value)
             self.view.feedback.showMoveHints(value)
 
         elif name == 'show_numbering':
-            menuItem = self.__getWidget('menu_view_numbering')
-            menuItem.set_active(value)
             self.view.feedback.showBoardNumbering(value)
 
         elif name == 'move_format':
-            self._gui.get_widget('menu_movef_%s' % value).set_active(True)
             self.view.setMoveFormat(value)
                 
         elif name == 'promotion_type':
-            try:
-                radio = self.__promotionRadioByType[value]
-            except KeyError:
-                glchess.config.default('promotion_type')
-            else:
-                radio.set_active(True)
-                
+            pass
+    
         elif name == 'board_view':
-            try:
-                radio = self.__boardViewRadioByType[value]
-            except KeyError:
-                glchess.config.default('board_view')
-            else:
-                radio.set_active(True)
-                
+            pass
+
         else:
             assert(False), 'Unknown config item: %s' % name
 
@@ -755,7 +727,7 @@ Please contact your system administrator to resolve these problems, until then y
         """Gtk+ callback"""
         window = self._gui.get_widget('log_window')
         if widget.get_active():
-            window.show()
+            window.present()
         else:
             window.hide()
 
@@ -870,8 +842,8 @@ Please contact your system administrator to resolve these problems, until then y
         self.__getWidget('navigation_box').set_sensitive(enable)
         
         enable = enable and self.view.gameResult is None
-        for widget in ('menu_resign', 'resign_button', 'menu_claim_draw'):
-            self.__getWidget(widget).set_sensitive(enable)
+        '''FIXME! for widget in ('menu_resign', 'resign_button', 'menu_claim_draw'):
+            self.__getWidget(widget).set_sensitive(enable)'''
 
     def _on_new_game_button_clicked(self, widget):
         """Gtk+ callback"""
@@ -905,6 +877,10 @@ Please contact your system administrator to resolve these problems, until then y
         """Gtk+ callback"""
         self.view.feedback.claimDraw()
 
+    def _on_preferences_clicked(self, widget):
+        """Gtk+ callback"""
+        self.preferences.setVisible(True)
+
     def _on_help_clicked(self, widget):
         """Gtk+ callback"""
         try:
@@ -939,6 +915,7 @@ Please contact your system administrator to resolve these problems, until then y
             return
         
         dialog = self.__aboutDialog = gtk.AboutDialog()
+        dialog.set_transient_for(self.mainWindow)
         dialog.set_name(APPNAME)
         dialog.set_version(VERSION)
         dialog.set_copyright(COPYRIGHT)
