@@ -196,12 +196,12 @@ class Scene(glchess.scene.Scene):
         self.chessSets = {'white': builtin_models.WhiteBuiltinSet(), 'black': builtin_models.BlackBuiltinSet()}
         
         self.whiteTexture = texture.Texture(os.path.join(TEXTURE_DIR, 'board.png'),
-                                              ambient = BOARD_AMBIENT, diffuse = BOARD_DIFFUSE,
-                                              specular = BOARD_SPECULAR, shininess = BOARD_SHININESS)
+                                            ambient = BOARD_AMBIENT, diffuse = BOARD_DIFFUSE,
+                                            specular = BOARD_SPECULAR, shininess = BOARD_SHININESS)
         self.blackTexture = texture.Texture(os.path.join(TEXTURE_DIR, 'board.png'),
-                                              ambient = BOARD_AMBIENT, diffuse = BOARD_DIFFUSE,
-                                              specular = BOARD_SPECULAR, shininess = BOARD_SHININESS)
-        
+                                            ambient = BOARD_AMBIENT, diffuse = BOARD_DIFFUSE,
+                                            specular = BOARD_SPECULAR, shininess = BOARD_SHININESS)
+
     def onRedraw(self):
         """This method is called when the scene needs redrawing"""
         pass
@@ -261,7 +261,7 @@ class Scene(glchess.scene.Scene):
         self.targetBoardAngle = angle
         
         if not animate:
-            self.boardAngle = angle
+            self.oldBoardAngle = self.boardAngle = angle
             self.feedback.onRedraw()
             return
         
@@ -285,7 +285,7 @@ class Scene(glchess.scene.Scene):
         """Render the scene.
         
         This requires an OpenGL context.
-        """        
+        """
         glClearColor(*BACKGROUND_COLOUR)
         glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT)
 
@@ -324,7 +324,7 @@ class Scene(glchess.scene.Scene):
             self.drawThrobber()
         else:
             self.drawPieces()
-
+            
     def getSquare(self, x, y):
         """Find the chess square at a given 2D location.
         
