@@ -50,9 +50,6 @@ class SwappableArea (gtk.Notebook):
             import traceback; traceback.print_exc()
             print 'forge on fearlessly...'
         self.set_current_page(self.main_page)
-        def redraw_page (*args):
-            self.get_nth_page(self.main_page).queue_draw()
-        gobject.timeout_add(100,redraw_page)
         self.running = None
         tmp_response = self.response
         self.response = None
