@@ -67,6 +67,7 @@ class NewOrSavedGameSelector (gconf_wrapper.GConfWrapper):
         self.glade.get_widget('newGameLabel').set_mnemonic_widget(
             self.new_game_view
             )
+        self.saved_games = saver.SudokuTracker().list_saved_games()
         self.make_new_game_model()
         self.new_game_view.set_model(self.new_game_model)
         self.new_game_view.set_markup_column(0)
@@ -91,12 +92,31 @@ class NewOrSavedGameSelector (gconf_wrapper.GConfWrapper):
     @simple_debug
     def make_new_game_model (self):
         # Description, Pixbuf, Puzzle (str)
-        self.new_game_model = gtk.ListStore(str,gtk.gdk.Pixbuf,str)        
+        self.new_game_model = gtk.ListStore(str,gtk.gdk.Pixbuf,str)
+        saved_games_to_exclude = [
+            g['game'].split('\n')[0] for g in self.saved_games
+            ]
         for cat in DR.ordered_categories:
             rng = DR.categories[cat]; label = DR.label_by_cat[cat]
             #puzzle,diff = self.sudoku_maker.get_new_puzzle(.01*random.randint(*[r*100 for r in rng]))
             #diff_val = diff.value
-            puzzle,diff_val = self.sudoku_maker.get_puzzles(1,[cat],new=True)[0]
+            puzzles = self.sudoku_maker.get_puzzles(1,[cat],new=True,
+                                                    exclude=saved_games_to_exclude
+                                                    )
+            if puzzles:
+                puzzle,diff_val = puzzles[0]
+            else:
+                print 'WARNING: Repeating puzzle for difficulty %s -- generate more puzzles to avoid this.'%cat
+                puzzles = self.sudoku_maker.get_puzzles(1,[cat],new=False)
+                if puzzles:
+                    puzzle,diff_val = puzzles[0]
+                    lpuz = list(puzzle)
+                    lpuz.reverse() # we reverse the puzzle so it at least looks different :-)
+                    puzzle = ''
+                    for n in lpuz: puzzle += n
+                else:
+                    print 'WARNING: No puzzle for difficulty',cat
+                    continue
             #print 'Got new puzzle for ',cat,'difficulty:',diff
             grid = sudoku.sudoku_grid_from_string(puzzle).grid
             self.new_game_model.append(('<b><i>'+label+'</i></b>',
@@ -111,17 +131,18 @@ class NewOrSavedGameSelector (gconf_wrapper.GConfWrapper):
     def make_saved_game_model (self):
         # Description, Image, Last-Access time (for sorting), Puzzle (jar)
         self.saved_game_model = gtk.ListStore(str,gtk.gdk.Pixbuf,int,gobject.TYPE_PYOBJECT)
-        t = saver.SudokuTracker()
-        for g in t.list_saved_games():
-            #print 'game',g
+        for g in self.saved_games:
             game = g['game'].split('\n')[0]
             grid = sudoku.sudoku_grid_from_string(game)
             sr = sudoku.SudokuRater(grid.grid)
             sdifficulty = sr.difficulty()
-            desc = "<b><i>%s</i></b>\n<span size='small'><i>Last played %s</i>\n<i>Played for %s.</i></span>"%(
-                _("%s puzzle")%sdifficulty.value_string(),
-                format_friendly_date(g['saved_at']),
-                format_time(g['timer.tot_time'],round_at=15,friendly=True)
+            lastPlayedText = _("Last Played %(timeAgo)s") % {'timeAgo': format_friendly_date(g['saved_at'])}
+            levelText =  _("%(level)s puzzle")% {'level': sdifficulty.value_string()}
+            durationText = _("Played for %(duration)s") % {'duration': format_time(g['timer.tot_time'],round_at=15,friendly=True)}
+            desc = "<b><i>%s</i></b>\n<span size='small'><i>%s</i>\n<i>%s.</i></span>"%(
+                levelText,
+                lastPlayedText,
+                durationText,
                 )
             #print 'Adding to saved...',g
             self.saved_game_model.append((
