@@ -77,7 +77,6 @@ enum {
 enum {
   NO_ACTION,
   SHOW_ACTION,
-  MAYBE_SHOW_ACTION,
   CLEAR_ACTION,
   FLAG_ACTION
 };
@@ -168,7 +167,7 @@ setup_sign (sign * signp, const char *file, guint minesize)
   if (signp->preimage) {
     signp->scaledpixbuf = games_preimage_render (signp->preimage,
 						 signp->width,
-						 signp->height, NULL);
+						 signp->height);
   }
 
   if (!signp->scaledpixbuf) {
@@ -676,10 +675,21 @@ gtk_minefield_check_field (GtkMineField * mfield, gint x, gint y)
 static void
 gtk_minefield_lose (GtkMineField * mfield)
 {
+  guint i, x, y;
+
   g_signal_emit (G_OBJECT (mfield),
 		 minefield_signals[EXPLODE_SIGNAL], 0, NULL);
+
   mfield->lose = 1;
-  gtk_widget_queue_draw (GTK_WIDGET (mfield));
+
+  /* draw mines and wrong markings */
+  for (i = 0; i <mfield->xsize * mfield->ysize; i++) {
+    if (mfield->mines[i].mined || mfield->mines[i].marked) {
+      y = i / mfield->xsize;
+      x = i % mfield->xsize;
+      gtk_mine_draw (mfield, x, y);
+    }
+  }
 }
 
 static void
@@ -970,7 +980,6 @@ gtk_minefield_motion_notify (GtkWidget * widget, GdkEventMotion * event)
   GtkMineField *mfield;
   guint x, y;
   gint c;
-  guint multi;
   guint minesize;
 
   g_return_val_if_fail (widget != NULL, 0);
@@ -984,15 +993,15 @@ gtk_minefield_motion_notify (GtkWidget * widget, GdkEventMotion * event)
   if (mfield->lose || mfield->win)
     return FALSE;
 
-  if (mfield->bdown[0] || mfield->bdown[1]) {
-    x = event->x / minesize;
-    y = event->y / minesize;
+  x = event->x / minesize;
+  y = event->y / minesize;
 
-    c = cell_idx (mfield, x, y);
-    if (c == -1)
-      return 0;
+  c = cell_idx (mfield, x, y);
+  if (c == -1)
+    return 0;
 
-    if (c != mfield->cdown) {
+  if (c != mfield->cdown) {
+    if (mfield->bdown[0] || mfield->bdown[1]) {
       mfield->mines[mfield->cdown].down = 0;
       gtk_mine_draw (mfield, mfield->cdownx, mfield->cdowny);
 
@@ -1005,10 +1014,18 @@ gtk_minefield_motion_notify (GtkWidget * widget, GdkEventMotion * event)
       mfield->mines[c].down = 1;
       gtk_mine_draw (mfield, x, y);
 
-      multi = (mfield->action == MAYBE_SHOW_ACTION) && mfield->mines[c].shown;
+      if (mfield->action == CLEAR_ACTION && mfield->mines[c].shown)
+        gtk_minefield_multi_press (mfield, x, y, c);
+    } else if (mfield->bdown[2]) {
+      /*  Update clicked field on right click drag. See bug #515497  */
+      mfield->mines[mfield->cdown].down = 0;
+      mfield->action = NO_ACTION;
+      gtk_mine_draw (mfield, mfield->cdownx, mfield->cdowny);
 
-      if (multi)
-	gtk_minefield_multi_press (mfield, x, y, c);
+      mfield->cdownx = x;
+      mfield->cdowny = y;
+      mfield->cdown = c;
+      mfield->mines[c].down = 1;
     }
   }
   return FALSE;
@@ -1041,10 +1058,10 @@ gtk_minefield_button_press (GtkWidget * widget, GdkEventButton * event)
     c = cell_idx (mfield, x, y);
     if (c == -1)
       return FALSE;
-
+      
     /* If this is the first button pressed (on a cell),
      * record where it was pressed. */
-    if (!mfield->bdown[0] && !mfield->bdown[1] && !mfield->bdown[2]) {
+    if (!mfield->bdown[0] && !mfield->bdown[1]) {
       mfield->cdownx = x;
       mfield->cdowny = y;
       mfield->cdown = c;
@@ -1067,9 +1084,9 @@ gtk_minefield_button_press (GtkWidget * widget, GdkEventButton * event)
      * about all the extra legacy crap. */
     switch (event->button) {
     case 1:
-      mfield->action = MAYBE_SHOW_ACTION;
-      if ((event->state & GDK_SHIFT_MASK) || (mfield->bdown[2]))
-	mfield->action = CLEAR_ACTION;
+      mfield->action = SHOW_ACTION;
+      if ((event->state & GDK_SHIFT_MASK) || (mfield->bdown[2]) || (mfield->mines[c].shown))
+        mfield->action = CLEAR_ACTION;
       break;
     case 2:
       mfield->action = CLEAR_ACTION;
@@ -1083,8 +1100,7 @@ gtk_minefield_button_press (GtkWidget * widget, GdkEventButton * event)
 
     /* Now actually do the actions. Most of the real work
      * is done in the button_release handler. */
-    if ((mfield->action == CLEAR_ACTION) ||
-	((mfield->action == MAYBE_SHOW_ACTION) && mfield->mines[c].shown)) {
+    if (mfield->action == CLEAR_ACTION) {
       gtk_minefield_multi_press (mfield, x, y, c);
     } else if (mfield->action == FLAG_ACTION && mfield->bdown[2] == 1) {
       gtk_minefield_toggle_mark (mfield, x, y);
@@ -1112,10 +1128,6 @@ gtk_minefield_button_release (GtkWidget * widget, GdkEventButton * event)
   if (mfield->lose || mfield->win)
     return FALSE;
 
-  if (mfield->action == MAYBE_SHOW_ACTION)
-    mfield->action = mfield->mines[mfield->cdown].shown ?
-      CLEAR_ACTION : SHOW_ACTION;
-
   if (event->button <= 3 && mfield->bdown[event->button - 1]) {
     switch (mfield->action) {
     case SHOW_ACTION:
